| Title: | Guidelines for Reporting About Network Data |
|---|---|
| Description: | Interactively applies the Guidelines for Reporting About Network Data (GRAND) to an 'igraph' object, and generates a uniform narrative or tabular description of the object. |
| Authors: | Zachary Neal [aut, cre] (ORCID: <https://orcid.org/0000-0003-3076-4995>) |
| Maintainer: | Zachary Neal <[email protected]> |
| License: | GPL-3 |
| Version: | 0.9.1 |
| Built: | 2026-05-29 09:49:25 UTC |
| Source: | https://github.com/cranhaven/cranhaven.r-universe.dev |
The grand function interactively adds information about a network and generates a narrative summary of the
network following the Guidelines for Reporting About Network Data.
grand(G, mode, help = FALSE, verbose = FALSE)grand(G, mode, help = FALSE, verbose = FALSE)
G |
An igraph object, with weights/signs (if present) stored in |
mode |
string: "interview" to interactively add information, or "statement" to generate a summary statement |
help |
boolean: Should interview prompts be accompanied by explanations and examples? |
verbose |
boolean: Should an extended summary be generated? |
An igraph object if mode == "interview", or a string if mode == "statement"
G <- igraph::make_graph("Zachary") #An example network #G <- grand(G, mode = "interview") #Interactively enter information... G <- grand_manual(G, #...or manually enter information name = "Zachary Karate Club", doi = "10.1086/jar.33.4.3629752", url = "https://networks.skewed.de/net/karate", vertex1 = "People", positive = "Friendship", mode = "Observation", year = "1977") grand(G, mode = "statement") #Display summary statementG <- igraph::make_graph("Zachary") #An example network #G <- grand(G, mode = "interview") #Interactively enter information... G <- grand_manual(G, #...or manually enter information name = "Zachary Karate Club", doi = "10.1086/jar.33.4.3629752", url = "https://networks.skewed.de/net/karate", vertex1 = "People", positive = "Friendship", mode = "Observation", year = "1977") grand(G, mode = "statement") #Display summary statement
The grand_manual function allows a user to manually and non-interactively add GRAND information to
an igraph object. Normally this information should be added interactively using
grand(mode = "interview").
grand_manual( G, name = NA, doi = NA, url = NA, vertex1 = NA, vertex2 = NA, positive = NA, negative = NA, weight = NA, level = NA, mode = NA, year = NA )grand_manual( G, name = NA, doi = NA, url = NA, vertex1 = NA, vertex2 = NA, positive = NA, negative = NA, weight = NA, level = NA, mode = NA, year = NA )
G |
An igraph object, with weights/signs (if present) stored in |
name |
string: Name of the network (e.g., Zachary Karate Club) |
doi |
string: DOI associated with the data (e.g., 10.1086/jar.33.4.3629752) |
url |
string: Link to data (e.g., https://networks.skewed.de/net/karate) |
vertex1 |
string: Entity represented by nodes in a unipartite network, or by |
vertex2 |
string: Entity represented by |
positive |
string: Relationship represented by (positive) edges (e.g., friendship) |
negative |
string: Relationship represented by negative edges, if present |
weight |
string: What the edge weights represent (e.g., frequency, intensity, multiplexity) |
level |
string: Scale on which edge weights are measured (e.g., continuous, count, ordinal, categorical) |
mode |
string: Mode of data collection (e.g., survey, interview, sensor, observation, archival, simulation) |
year |
numeric: Year in which data was collected (e.g., 1977) |
An igraph object
G <- igraph::make_graph("Zachary") #An example network G <- grand_manual(G, #Manually enter information name = "Zachary Karate Club", doi = "10.1086/jar.33.4.3629752", url = "https://networks.skewed.de/net/karate", vertex1 = "People", positive = "Friendship", mode = "Observation", year = "1977") grand(G, mode = "statement") #Display summary statementG <- igraph::make_graph("Zachary") #An example network G <- grand_manual(G, #Manually enter information name = "Zachary Karate Club", doi = "10.1086/jar.33.4.3629752", url = "https://networks.skewed.de/net/karate", vertex1 = "People", positive = "Friendship", mode = "Observation", year = "1977") grand(G, mode = "statement") #Display summary statement